pub struct RigidBodyQuery {Show 18 fields
pub entity: Entity,
pub rb: Ref<'static, RigidBody>,
pub position: &'static mut Position,
pub rotation: &'static mut Rotation,
pub previous_position: &'static mut PreviousPosition,
pub previous_rotation: &'static mut PreviousRotation,
pub accumulated_translation: &'static mut AccumulatedTranslation,
pub linear_velocity: &'static mut LinearVelocity,
pub angular_velocity: &'static mut AngularVelocity,
pub mass: &'static mut Mass,
pub inverse_mass: &'static mut InverseMass,
pub inertia: &'static mut Inertia,
pub inverse_inertia: &'static mut InverseInertia,
pub center_of_mass: &'static mut CenterOfMass,
pub friction: &'static Friction,
pub restitution: &'static Restitution,
pub locked_axes: Option<&'static LockedAxes>,
pub dominance: Option<&'static Dominance>,
/* private fields */
}Expand description
A WorldQuery to make querying and modifying rigid bodies more convenient.
Fields
entity: Entityrb: Ref<'static, RigidBody>position: &'static mut Positionrotation: &'static mut Rotationprevious_position: &'static mut PreviousPositionprevious_rotation: &'static mut PreviousRotationaccumulated_translation: &'static mut AccumulatedTranslationlinear_velocity: &'static mut LinearVelocityangular_velocity: &'static mut AngularVelocitymass: &'static mut Massinverse_mass: &'static mut InverseMassinertia: &'static mut Inertiainverse_inertia: &'static mut InverseInertiacenter_of_mass: &'static mut CenterOfMassfriction: &'static Frictionrestitution: &'static Restitutionlocked_axes: Option<&'static LockedAxes>dominance: Option<&'static Dominance>Trait Implementations
Sourceimpl QueryData for RigidBodyQuery
SAFETY: we assert fields are readonly below
impl QueryData for RigidBodyQuery
SAFETY: we assert fields are readonly below
Sourcetype ReadOnly = RigidBodyQueryReadOnly
type ReadOnly = RigidBodyQueryReadOnly
The read-only variant of this
QueryData, which satisfies the ReadOnlyQueryData trait.Sourceimpl WorldQuery for RigidBodyQuery
impl WorldQuery for RigidBodyQuery
Sourceunsafe fn set_archetype<'__w>(
_fetch: &mut <Self as WorldQuery>::Fetch<'__w>,
_state: &Self::State,
_archetype: &'__w Archetype,
_table: &'__w Table,
)
unsafe fn set_archetype<'__w>( _fetch: &mut <Self as WorldQuery>::Fetch<'__w>, _state: &Self::State, _archetype: &'__w Archetype, _table: &'__w Table, )
SAFETY: we call set_archetype for each member that implements Fetch
Sourceunsafe fn set_table<'__w>(
_fetch: &mut <Self as WorldQuery>::Fetch<'__w>,
_state: &Self::State,
_table: &'__w Table,
)
unsafe fn set_table<'__w>( _fetch: &mut <Self as WorldQuery>::Fetch<'__w>, _state: &Self::State, _table: &'__w Table, )
SAFETY: we call set_table for each member that implements Fetch
Sourceunsafe fn fetch<'__w>(
_fetch: &mut <Self as WorldQuery>::Fetch<'__w>,
_entity: Entity,
_table_row: TableRow,
) -> <Self as WorldQuery>::Item<'__w>
unsafe fn fetch<'__w>( _fetch: &mut <Self as WorldQuery>::Fetch<'__w>, _entity: Entity, _table_row: TableRow, ) -> <Self as WorldQuery>::Item<'__w>
SAFETY: we call fetch for each member that implements Fetch.
Sourceconst IS_DENSE: bool
const IS_DENSE: bool
Returns true if (and only if) every table of every archetype matched by this fetch contains
all of the matched components. This is used to select a more efficient “table iterator”
for “dense” queries. If this returns true,
WorldQuery::set_table must be used before
WorldQuery::fetch can be called for iterators. If this returns false,
WorldQuery::set_archetype must be used before WorldQuery::fetch can be called for
iterators.Sourcetype Item<'__w> = RigidBodyQueryItem<'__w>
type Item<'__w> = RigidBodyQueryItem<'__w>
The item returned by this
WorldQuery
For QueryData this will be the item returned by the query.
For QueryFilter this will be either (), or a bool indicating whether the entity should be included
or a tuple of such things.Sourcetype Fetch<'__w> = RigidBodyQueryFetch<'__w>
type Fetch<'__w> = RigidBodyQueryFetch<'__w>
Per archetype/table state used by this
WorldQuery to fetch Self::ItemSourcetype State = RigidBodyQueryState
type State = RigidBodyQueryState
State used to construct a
Self::Fetch. This will be cached inside QueryState,
so it is best to move as much data / computation here as possible to reduce the cost of
constructing Self::Fetch.Sourcefn shrink<'__wlong: '__wshort, '__wshort>(
item: <RigidBodyQuery as WorldQuery>::Item<'__wlong>,
) -> <RigidBodyQuery as WorldQuery>::Item<'__wshort>
fn shrink<'__wlong: '__wshort, '__wshort>( item: <RigidBodyQuery as WorldQuery>::Item<'__wlong>, ) -> <RigidBodyQuery as WorldQuery>::Item<'__wshort>
This function manually implements subtyping for the query items.
Sourceunsafe fn init_fetch<'__w>(
_world: UnsafeWorldCell<'__w>,
state: &Self::State,
_last_run: Tick,
_this_run: Tick,
) -> <Self as WorldQuery>::Fetch<'__w>
unsafe fn init_fetch<'__w>( _world: UnsafeWorldCell<'__w>, state: &Self::State, _last_run: Tick, _this_run: Tick, ) -> <Self as WorldQuery>::Fetch<'__w>
Creates a new instance of this fetch. Read more
Sourcefn update_component_access(
state: &Self::State,
_access: &mut FilteredAccess<ComponentId>,
)
fn update_component_access( state: &Self::State, _access: &mut FilteredAccess<ComponentId>, )
Sourcefn init_state(world: &mut World) -> RigidBodyQueryState
fn init_state(world: &mut World) -> RigidBodyQueryState
Creates and initializes a
State for this WorldQuery type.Sourcefn get_state(components: &Components) -> Option<RigidBodyQueryState>
fn get_state(components: &Components) -> Option<RigidBodyQueryState>
Sourcefn matches_component_set(
state: &Self::State,
_set_contains_id: &impl Fn(ComponentId) -> bool,
) -> bool
fn matches_component_set( state: &Self::State, _set_contains_id: &impl Fn(ComponentId) -> bool, ) -> bool
Sourcefn set_access(_state: &mut Self::State, _access: &FilteredAccess<ComponentId>)
fn set_access(_state: &mut Self::State, _access: &FilteredAccess<ComponentId>)
Sets available accesses for implementors with dynamic access such as
FilteredEntityRef
or FilteredEntityMut. Read moreAuto Trait Implementations
impl !UnwindSafe for RigidBodyQuery
impl Freeze for RigidBodyQuery
impl RefUnwindSafe for RigidBodyQuery
impl Send for RigidBodyQuery
impl Sync for RigidBodyQuery
impl Unpin for RigidBodyQuery
impl UnsafeUnpin for RigidBodyQuery