pub struct Sensor;
A component that marks a Collider as a sensor, also known as a trigger.

Sensor colliders send collision events and register intersections, but allow other bodies to pass through them. This is often used to detect when something enters or leaves an area or is intersecting some shape.

Example

use bevy::prelude::*;
use bevy_xpbd_2d::prelude::*;

fn setup(mut commands: Commands) {
    // Spawn a static body with a sensor collider.
    // Other bodies will pass through, but it will still send collision events.
    commands.spawn((RigidBody::Static, Collider::ball(0.5), Sensor));
}