Struct bevy_xpbd_2d::SubstepSchedule
source · pub struct SubstepSchedule;Expand description
The substepping schedule that runs in PhysicsStepSet::Substeps.
The number of substeps per physics step is configured through the SubstepCount resource.
See SubstepSet for the system sets that are run in this schedule.